#include ".\divisional_state_density_report_generator.h"
 
void Xport_report_suite::divisional_state_density_report_generator::create_header(document& doc) const
{
  *doc.title() << "Divisional State Density Report";

  markup::iterator it = doc.body()->insert(element(Xport::div, "id_heading"));
  *it << (element(h1) << "US Divisional State Density Report");
}

void Xport_report_suite::divisional_state_density_report_generator::create_report_body(document& doc) const
{
  int dvsn = new_england;
  for (; dvsn <= pacific; ++dvsn) {
    element tbl(table);
    create_division_table(tbl, dvsn);

    *doc.body() << tbl;
  }
}

void Xport_report_suite::divisional_state_density_report_generator::create_division_table(element& tbl, int dvsn) const
{
  std::vector<state_info> siv;
  us_state_report_generator::get_divisional_state_data(dvsn, siv, sf_density, descending);
  std::vector<state_info>::const_iterator it = siv.begin();

  create_table_header(tbl, dvsn);
  int rows = 0;

  for (; it != siv.end(); ++it, ++rows) {
    element row(tr);
    row << (element(td) << it->name());
    row << (element(td) << it->abbr());
    row << (element(td, "", "density") << numeric_format(it->density(), 2));
    row << (element(td, "", "density_rank") << numeric_format(it->density_rank()));
    tbl << row;
  }

  if (rows > 1) {
    markup::iterator tbl_it = tbl.begin();
    ++tbl_it;
    tbl_it = tbl_it->insert(element(td, "", "img_cell"));
    tbl_it->attribute(rowspan, numeric_format(rows + 1));
    tbl_it = tbl_it->insert(element(img));
    std::ostringstream img_path;
    img_path << "../img/division_" << dvsn << ".png";
    tbl_it->attribute(src, img_path.str());
  }

}

void Xport_report_suite::divisional_state_density_report_generator::create_table_header(element& tbl, int dvsn) const
{
  markup::iterator it = tbl.insert(element(tr, "", "division_name"));
  it = it->insert(element(th));
  it->attribute(colspan, "5");
  *it << us_state_report_generator::get_division_name(dvsn);

  it = tbl.insert(element(tr, "", "titles"));
  *it << (element(th) << "State");
  *it << (element(th) << "Abbr");
  *it << (element(th) << "Density (sq mi)");
  *it << (element(th) << "Density Rank");
}

void Xport_report_suite::divisional_state_density_report_generator::create_footer(document& doc) const
{
  element footer(Xport::div, "id_footer");
  markup::iterator it = footer.insert(element(p) << "xhtml report and stylesheet created by ");
  it = it->insert(element(a));
  it->attribute(href, "http://www.xportpro.com");
  *it << "Xport";
  *doc.body() << footer;
  
}

void Xport_report_suite::divisional_state_density_report_generator::create_stylesheet(document& doc, stylesheet& ss) const
{
  stylesheet::iterator it = ss.insert(stylesheet_rule("#id_heading"));
  *it << declaration(css::width, "70%")
      << declaration(css::height, "100px")
      << declaration(margin_left, "auto")
      << declaration(margin_right, "auto")
      << declaration(margin_top, "10px")
      << declaration(margin_bottom, "50px")
      << declaration(css::color, "#002f2f")
      << declaration(css::border, "3px solid #046380")
      << declaration(border_left, "40px solid #046380")
      << declaration(background_color, "#efecca");

  it = ss.insert(stylesheet_rule("#id_heading h1"));
  *it << declaration(text_align, "center")
      << declaration(padding_top, "30px")
      << declaration(css::margin, "0px");

  it = ss.insert(stylesheet_rule("table"));
  *it << declaration(css::width, "60%")
      << declaration(margin_left, "auto")
      << declaration(margin_right, "auto")
      << declaration(css::border, "3px solid #046380")
      << declaration(border_left, "40px solid #046380")
      << declaration(margin_bottom, "50px")
      << declaration(css::color, "#002f2f")
      << declaration(border_collapse, "collapse");

  it = ss.insert(stylesheet_rule("tr.division_name th"));
  *it << declaration(background_color, "#e6e2af")
      << declaration(border_bottom, "2px solid #002f2f")
      << declaration(line_height, "200%")
      << declaration(font_size, "larger")
      << declaration(font_weight, "bold");

  it = ss.insert(stylesheet_rule("tr.titles th"));
  *it << declaration(background_color, "#a7a37e")
      << declaration(border_bottom, "2px solid #002f2f")
      << declaration(text_align, "left")
      << declaration(padding_left, "10px");

  it = ss.insert(stylesheet_rule(".img_cell"));
  *it << declaration(css::width, "220px")
      << declaration(background_color, "white")
      << declaration(border_left, "2px solid #002f2f");

  it = ss.insert(stylesheet_rule(".img_cell img"));
  *it << declaration(css::width, "200px")
      << declaration(css::height, "200px");

  it = ss.insert(stylesheet_rule("td"));
  *it << declaration(background_color, "#efecca")
      << declaration(padding_left, "10px");

  it = ss.insert(stylesheet_rule("td.density"));
  *it << declaration(font_weight, "bold");

  it = ss.insert(stylesheet_rule("td.density_rank"));
  *it << declaration(padding_left, "30px")
      << declaration(font_weight, "bold");

  it = ss.insert(stylesheet_rule("#id_footer"));
  *it << declaration(css::width, "40%")
      << declaration(css::height, "30px")
      << declaration(margin_left, "auto")
      << declaration(margin_right, "auto")
      << declaration(background_color, "#a7a37e")
      << declaration(css::border, "4px ridge #046380");

  it = ss.insert(stylesheet_rule("#id_footer p"));
  *it << declaration(text_align, "center")
      << declaration(padding_top, "5px")
      << declaration(css::margin, "0px");


  element css_link(Xport::link);
  css_link.attribute(rel, "stylesheet");
  css_link.attribute(type, "text/css");
  css_link.attribute(href, "divisional_state_density_report.css");
  *doc.head() << css_link;

}



