#pragma once
 
namespace Xport_report_suite
{
  enum state_sort_field {sf_name, sf_abbr, sf_capital, sf_largest_city, sf_nickname, sf_slogan, sf_tree, sf_flower, sf_population,
    sf_population_rank, sf_area, sf_area_rank, sf_density, sf_density_rank, sf_pct_water, sf_admit_date,
    sf_region, sf_division};
  enum sort_order { ascending, descending };

  // unary predicate functors
  struct region_up
  {
    region_up(int rgn) : region(rgn) {}
    bool operator() (const state_info& si) { return si.region() == region; }
    const int region;
  };

  struct division_up
  {
    division_up(int div) : division(div) {}
    bool operator() (const state_info& si) { return si.division() == division; }
    const int division;
  };

  // generic comp
  struct state_comp {
    state_comp(state_sort_field sf, sort_order so) : sort_field(sf), order(so) {}
    bool operator() (const state_info& lhs, const state_info& rhs)
    {
      switch (sort_field)
      {
      case sf_name: return (order == ascending ? lhs.name() < rhs.name() : rhs.name() < lhs.name()); break;
      case sf_abbr: return (order == ascending ? lhs.abbr() < rhs.abbr() : rhs.abbr() < lhs.abbr()); break;
      case sf_capital: return (order == ascending ? lhs.capital() < rhs.capital() : rhs.capital() < lhs.capital()); break;
      case sf_largest_city: return (order == ascending ? lhs.largest_city() < rhs.largest_city() : rhs.largest_city() < lhs.largest_city()); break;
      case sf_nickname: return (order == ascending ? lhs.nickname() < rhs.nickname() : rhs.nickname() < lhs.nickname()); break;
      case sf_slogan: return (order == ascending ? lhs.slogan() < rhs.slogan() : rhs.slogan() < rhs.slogan()); break;
      case sf_population: return (order == ascending ? lhs.population() < rhs.population() : rhs.population() < lhs.population()); break;
      case sf_population_rank: return (order == ascending ? lhs.population_rank() < rhs.population_rank() : rhs.population_rank() < lhs.population_rank()); break;
      case sf_area: return (order == ascending ? lhs.area() < rhs.area() : rhs.area() < lhs.area()); break;
      case sf_area_rank: return (order == ascending ? lhs.area_rank() < rhs.area_rank() : rhs.area_rank() < lhs.area_rank()); break;
      case sf_density: return (order == ascending ? lhs.density() < rhs.density() : rhs.density() < lhs.density()); break;
      case sf_density_rank: return (order == ascending ? lhs.density_rank() < rhs.density_rank() : rhs.density_rank() < lhs.density_rank()); break;
      case sf_admit_date: return (order == ascending ? lhs.admit_date() < rhs.admit_date() : rhs.admit_date() < lhs.admit_date()); break;
      case sf_region: return lhs.region() < rhs.region(); break;
      case sf_division: return lhs.division() < rhs.division(); break;
      default: return false; break;
      }
    }

    state_sort_field sort_field;
    sort_order order;
  };
}

