#include "xhtml_doc.h"
#include "state_data.h"
#include "regional_state_area_report_generator.h"
#include "divisional_state_area_report_generator.h"
#include "divisional_state_capital_report_generator.h"
#include "regional_state_capital_report_generator.h"
#include "divisional_state_density_report_generator.h"
#include "regional_state_density_report_generator.h"
#include "state_capital_report_generator.h"
#include "state_area_report_generator.h"
#include "state_density_report_generator.h"
#include <string>
#include <sstream>
 
void create_reports();
void create_report(const Xport_report_suite::us_state_report_generator& rpt_gen);

int main(int argc, char* argv[])
{
  // create all reports
  create_reports();

  return 0;
}


void create_reports() 
{
  using namespace Xport_report_suite;

  // area reports
  create_report(state_area_report_generator());
  create_report(divisional_state_area_report_generator());
  create_report(regional_state_area_report_generator());

  // state capital reports
  create_report(state_capital_report_generator());
  create_report(divisional_state_capital_report_generator());
  create_report(regional_state_capital_report_generator());

  // density reports
  create_report(state_density_report_generator());
  create_report(divisional_state_density_report_generator());
  create_report(regional_state_density_report_generator());
}

void create_report(const Xport_report_suite::us_state_report_generator& rpt_gen)
{
  // create root doc of the specified doctype
  document doc(root_doc);
  // create stylesheet
  stylesheet ss;

  // generate report
  rpt_gen.generate_report(doc, ss);

  // specify path/filename for document
  std::ostringstream path;
  path << rpt_gen.report_path() << ".htm";

  // insure output folders are created
  rpt_gen.create_directory();

  // write document
  doc.write(path.str());

  // specify path for stylesheet
  path.str("");
  path << rpt_gen.report_path() << ".css";

  // write stylesheet
  ss.write(path.str());
}    
